@@ -75,6 +75,7 @@ void TwitterApiPostWidget::initUi()
     KAction *actRep = new KAction(KIcon("edit-undo"), i18n("Reply to %1", currentPost().author.userName), menu);
     menu->addAction(actRep);
     connect( actRep, SIGNAL(triggered(bool)), SLOT(slotReply()) );
+    connect( btnRe, SIGNAL(clicked(bool)), SLOT(slotReply()) );
 
     KAction *actWrite = new KAction( KIcon("document-edit"), i18n("Write to %1", currentPost().author.userName),
                                      menu );
@@ -88,7 +89,7 @@ void TwitterApiPostWidget::initUi()
     }
 
     menu->setDefaultAction(actRep);
-    btnRe->setMenu(menu);
+    btnRe->setDelayedMenu(menu);
 
     if( !currentPost().isPrivate ) {
         d->btnFav = addButton( "btnFavorite",i18nc( "@info:tooltip", "Favorite" ), "rating" );
@@ -109,7 +110,7 @@ QString TwitterApiPostWidget::generateSign()
     QString profUrl = currentAccount()->microblog()->profileUrl(currentAccount(),
                                                                 currentPost().author.userName);
     sign = "<b><a href='user://"+currentPost().author.userName+"' title=\"" +
-    currentPost().author.description + "\">" + currentPost().author.userName +
+    Qt::escape(currentPost().author.description) + "\">" + currentPost().author.userName +
     "</a> - </b>";
     //<img src=\"icon://web\" />
     sign += "<a href=\"" + currentPost().link +
@@ -163,7 +164,13 @@ void TwitterApiPostWidget::slotReply()
         TwitterApiAccount *account= qobject_cast<TwitterApiAccount*>( currentAccount() );
         d->mBlog->showDirectMessageDialog( account, currentPost().author.userName );
     } else {
-        emit reply( QString("@%1").arg(currentPost().author.userName), currentPost().postId );
+        QString replyto = QString("@%1").arg(currentPost().author.userName);
+        QString postId = currentPost().postId;
+        if( !currentPost().repeatedFromUsername.isEmpty() ){
+            replyto.prepend(QString("@%1 ").arg(currentPost().repeatedFromUsername));
+            postId = currentPost().repeatedPostId;
+        }
+        emit reply( replyto, postId );
     }
 }
 
@@ -205,7 +212,6 @@ void TwitterApiPostWidget::slotSetFavorite(Choqok::Account *theAccount, const QS
                    this, SLOT(slotSetFavorite(Choqok::Account*,QString)) );
         disconnect(d->mBlog, SIGNAL(favoriteCreated(Choqok::Account*,QString)),
                    this, SLOT(slotSetFavorite(Choqok::Account*,QString)) );
-        ///TODO Notify!
     }
 }
 
