@@ -26,14 +26,15 @@
 #define CHOQOK_CHOQOKTOOLS_H
 
 #include <QtCore/QObject>
+#include <QtCore/QUrl>
 #include "choqok_export.h"
-#include <QUrl>
-
 
 namespace Choqok {
 
 void CHOQOK_EXPORT openUrl( const QUrl &url );
 
+QString CHOQOK_EXPORT qoauthErrorText(int code);
+
 }
 
 #endif // CHOQOK_CHOQOKTOOLS_H
