@@ -28,6 +28,7 @@
 #include <KDE/KNotification>
 #include <klocalizedstring.h>
 #include "choqok_export.h"
+#include <QObject>
 
 namespace Choqok
 {
@@ -36,25 +37,18 @@ class CHOQOK_EXPORT NotifyManager
 {
 public:
     ~NotifyManager();
-//     static NotifyManager *self();
 
     static void error( const QString &message , const QString &title = i18n("Error") );
     static void success( const QString &message, const QString &title = i18n("Success") );
 
     static void newPostArrived( const QString& message, const QString& title = i18n("New posts") );
-
     static void shortening( const QString& message, const QString& title = i18n("Shortening a URL") );
 
-protected:
-    NotifyManager();
-    static void triggerNotify( const QString &eventId, const QString &title,
-                          const QString &message,
-                          KNotification::NotificationFlags flags = KNotification::CloseOnTimeout );
+private Q_SLOTS:
+    void slotConfigChanged();
 
 private:
-//     static NotifyManager *m_self;
-    class Private;
-    Private * const d;
+    NotifyManager();
 };
 }
 #endif // NOTIFYMANAGER_H
