@@ -32,6 +32,7 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include <sonnet/speller.h>
 #include <QMenu>
 #include <QTimer>
+#include <KAction>
 
 namespace Choqok {
 namespace UI{
@@ -77,6 +78,8 @@ TextEdit::TextEdit(uint charLimit /*= 0*/, QWidget* parent /*= 0*/)
     connect(BehaviorSettings::self(), SIGNAL(configChanged()), SLOT(settingsChanged()) );
 
     QTimer::singleShot(1000, this, SLOT(setupSpeller()));
+    connect(this, SIGNAL(aboutToShowContextMenu(QMenu*)),
+            SLOT(slotAboutToShowContextMenu(QMenu*)));
 }
 
 TextEdit::~TextEdit()
@@ -169,21 +172,33 @@ void TextEdit::updateRemainingCharsCount()
     }
 }
 
-void TextEdit::contextMenuEvent(QContextMenuEvent* event)
+void TextEdit::slotAboutToShowContextMenu(QMenu* menu)
 {
-    QMenu *menu = mousePopupMenu();
     if(menu){
         kDebug();
-        QAction *act = new QAction(i18n("Set spell check language"), menu);
+        KAction *act = new KAction(i18n("Set spell check language"), menu);
         act->setMenu(d->langActions);
         menu->addAction(act);
-        menu->exec(event->globalPos());
-        event->accept();
-    } else {
-        KTextEdit::contextMenuEvent(event);
+
+        KAction *shorten = new KAction(i18nc("Replcae URLs by a shortened URL", "Shorten URLs"), menu);
+        connect(shorten, SIGNAL(triggered(bool)), SLOT(shortenUrls()));
+        menu->addAction(shorten);
     }
 }
 
+void TextEdit::shortenUrls()
+{
+    kDebug();
+    QTextCursor cur = textCursor();
+    if( !cur.hasSelection() ){
+        cur.select(QTextCursor::BlockUnderCursor);
+    }
+    QString shortened = ShortenManager::self()->parseText( cur.selectedText() );
+    cur.removeSelectedText();
+    cur.insertText(shortened);
+    setTextCursor(cur);
+}
+
 void TextEdit::slotChangeSpellerLanguage()
 {
     QAction *act = qobject_cast<QAction*>(sender());
