@@ -111,6 +111,8 @@ public:
 
     QStringList urls();
 
+    TimelineWidget *timelineWidget() const;
+
     /**
      * Plugins can add status specific actions and process them internally
      * 
@@ -217,6 +219,7 @@ protected:
     static const QString webIconText;
     static const QString ownText;
     static const QString otherText;
+    static const QRegExp dirRegExp;
 
     void setAvatarText( const QString &text );
     QString avatarText() const;
