@@ -49,6 +49,7 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include "laconicacomposerwidget.h"
 #include "mediamanager.h"
 #include <choqokappearancesettings.h>
+#include "twitterapihelper/twitterapitimelinewidget.h"
 
 K_PLUGIN_FACTORY( MyPluginFactory, registerPlugin < LaconicaMicroBlog > (); )
 K_EXPORT_PLUGIN( MyPluginFactory( "choqok_laconica" ) )
@@ -98,7 +99,7 @@ Choqok::UI::MicroBlogWidget * LaconicaMicroBlog::createMicroBlogWidget( Choqok::
 Choqok::UI::TimelineWidget * LaconicaMicroBlog::createTimelineWidget( Choqok::Account *account,
                                                                  const QString &timelineName, QWidget *parent )
 {
-    return new Choqok::UI::TimelineWidget(account, timelineName, parent);
+    return new TwitterApiTimelineWidget(account, timelineName, parent);
 }
 
 Choqok::UI::PostWidget* LaconicaMicroBlog::createPostWidget(Choqok::Account* account,
@@ -238,9 +239,8 @@ void LaconicaMicroBlog::requestFriendsScreenName(TwitterApiAccount* theAccount,
     KUrl url = account->apiUrl();
     url.addPath( QString("/statuses/friends.%1").arg(format));
     QOAuth::ParamMap params;
-    if(account->usingOAuth()){
+    if( page > 1 ) {
         params.insert( "page", QByteArray::number( page ) );
-    } else {
         url.addQueryItem( "page", QString::number( page ) );
     }
 
@@ -249,7 +249,8 @@ void LaconicaMicroBlog::requestFriendsScreenName(TwitterApiAccount* theAccount,
         kDebug() << "Cannot create an http GET request!";
         return;
     }
-    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, url, QOAuth::GET, params));
+    job->addMetaData("customHTTPHeader", "Authorization: " + authorizationHeader(account, url,
+                                                                                 QOAuth::GET, params));
     mJobsAccount[job] = theAccount;
     connect( job, SIGNAL( result( KJob* ) ), this, SLOT( slotRequestFriendsScreenName(KJob*) ) );
     job->start();
