@@ -27,7 +27,6 @@ along with this program; if not, see http://www.gnu.org/licenses/
 #include "editaccountwidget.h"
 #include <QWidget>
 #include "ui_twittereditaccount_base.h"
-#define OAUTH
 
 namespace QOAuth {
 class Interface;
@@ -60,18 +59,16 @@ public:
     * @Return new or modified account. OR 0L on failure.
     */
     virtual Choqok::Account *apply();
-#ifdef OAUTH
+
 protected slots:
     virtual void authorizeUser();
-#endif
+
 protected:
     void loadTimelinesTableState();
     void saveTimelinesTableState();
-#ifdef OAUTH
     virtual void getPinCode();
     void setAuthenticated(bool authenticated);
     bool isAuthenticated;
-#endif
     TwitterMicroBlog *mBlog;
     TwitterAccount *mAccount;
     QProgressBar *progress;
