@@ -34,7 +34,7 @@
 #include <choqoktools.h>
 
 const QRegExp TwitterPostWidget::mTwitterUserRegExp( "([\\s\\W]|^)@([a-z0-9_]+){1,20}", Qt::CaseInsensitive );
-const QRegExp TwitterPostWidget::mTwitterTagRegExp("([\\s]|^)#([a-z0-9_]+)", Qt::CaseInsensitive );
+const QRegExp TwitterPostWidget::mTwitterTagRegExp("([\\s]|^)#([a-z0-9_\\x00c4\\x00e4\\x00d6\\x00f6\\x00dc\\x00fc\\x00df]+)", Qt::CaseInsensitive );
 
 TwitterPostWidget::TwitterPostWidget(Choqok::Account* account, const Choqok::Post& post, QWidget* parent): TwitterApiPostWidget(account, post, parent)
 {
@@ -54,7 +54,9 @@ void TwitterPostWidget::initUi()
         QAction *repeat = new QAction(i18n("Retweet"), menu);
         repeat->setToolTip(i18n("Retweet post using API"));
         connect( repeat, SIGNAL(triggered(bool)), SLOT(repeatPost()) );
-        menu->addAction(repeat);
+        // If person protects their acc, we will use simple adding RT before message
+        if (!currentPost().author.isProtected)
+            menu->addAction(repeat);
         menu->addAction(resend);
         btn->setMenu(menu);
     }
